@@ -1,22 +1,29 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/article_image.php,v 1.9.2.8 2007/03/02 12:23:13 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/article_image.php,v 1.9.2.9 2008/02/21 20:22:36 marclaporte Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
-# $Header: /cvsroot/tikiwiki/tiki/article_image.php,v 1.9.2.8 2007/03/02 12:23:13 luciash Exp $
 
-// application to display an image from the database with 
+// application to display an image from the database with
 // option to resize the image dynamically creating a thumbnail on the fly.
 
+require_once ('tiki-setup.php');
+
+if ($feature_articles != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_articles");
+
+	$smarty->display("error.tpl");
+	die;
+}
+
 if (!isset($_REQUEST["id"])) {
 	die;
 }
 
-include_once ('lib/init/initlib.php');
-include_once ('tiki-setup_base.php');
+
 
 $topiccachefile = "temp";
 if ($tikidomain) { $topiccachefile.= "/$tikidomain"; }
