@@ -1,21 +1,28 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/banner_image.php,v 1.8.2.6 2007/03/02 12:23:28 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/banner_image.php,v 1.8.2.7 2008/02/21 20:47:50 marclaporte Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
-# $Header: /cvsroot/tikiwiki/tiki/banner_image.php,v 1.8.2.6 2007/03/02 12:23:28 luciash Exp $
 
-// application to display an image from the database with 
+// application to display an image from the database with
 // option to resize the image dynamically creating a thumbnail on the fly.
+
+// Initialization
+include_once ('tiki-setup.php');
+
+if ($feature_banners != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_banners");
+	$smarty->display("error.tpl");
+	die;
+}
+
 if (!isset($_REQUEST["id"])) {
 	die;
 }
 
-include_once("lib/init/initlib.php");
-include_once ('db/tiki-db.php');
 
 $bannercachefile = "temp";
 if ($tikidomain) { $bannercachefile.= "/$tikidomain"; }
