@@ -1,12 +1,18 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/display_banner.php,v 1.12.2.3 2007/03/02 12:23:26 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/display_banner.php,v 1.12.2.4 2008/02/21 20:47:50 marclaporte Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
-# $Header: /cvsroot/tikiwiki/tiki/display_banner.php,v 1.12.2.3 2007/03/02 12:23:26 luciash Exp $
+include_once ('tiki-setup.php');
+
+if ($feature_banners != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_banners");
+	$smarty->display("error.tpl");
+	die;
+}
 
 // Only to be called from edit_banner or view_banner to display the banner without adding
 // impressions to the banner
@@ -14,10 +20,7 @@ if (!isset($_REQUEST["id"])) {
 	die;
 }
 
-include_once("lib/init/initlib.php");
-include_once ('db/tiki-db.php');
-include_once ('lib/tikilib.php');
-$tikilib = new Tikilib($dbTiki);
+
 include_once ('lib/banners/bannerlib.php');
 
 if (!isset($bannerlib)) {
