@@ -1155,8 +1155,8 @@ class Comments extends TikiLib {
 	    $now = date("U");
 	    $oldage = $now - $age;
 	    $query = "select `threadId` from `tiki_comments` where
-	    `parentId`=0  and `commentDate`<?";
-	    $result = $this->query($query, array( (int) $oldage ));
+	    `parentId`=0  and `commentDate`<? and `object`=? and `objectType` = 'forum'";
+	    $result = $this->query($query, array( (int) $oldage, $forumId ));
 
 	    while ($res = $result->fetchRow()) {
 		// Check if this old top level thread has replies
