@@ -1,6 +1,6 @@
 <?php
 /** \file
- * $Header: /cvsroot/tikiwiki/tiki/lib/debug/debugger-common.php,v 1.3 2003/08/07 04:34:03 rossta Exp $
+ * $Header: /cvsroot/tikiwiki/tiki/lib/debug/debugger-common.php,v 1.3.12.1 2008/02/21 19:10:04 marclaporte Exp $
  *
  * \brief Commonly used stuff
  *
@@ -8,6 +8,13 @@
  *
  */
 
+//this script may only be included - so its better to die if called directly.
+if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
+  header("location: index.php");
+  exit;
+}
+
+
 /// Result not available
 define('NO_RESULT', 0);
 
