@@ -1,4 +1,9 @@
 <?php
+if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
+  header("location: index.php");
+  exit;
+}
+
 $list = array();
 if( is_array( $_SESSION['tiki_cookie_jar'] ) )
 	foreach( $_SESSION['tiki_cookie_jar'] as $name=>$value )
