@@ -358,7 +358,7 @@ class UsersLib extends TikiLib {
 			// see if we can create a new account
 			if ($pam_create_tiki) {
 			    // need to make this better! *********************************************************
-			    $result = $this->add_user($user, $pass, '', '');
+			    $result = $this->add_user($user, $pass, '');
 
 			    // if it worked ok, just log in
 			    if ($result == USER_VALID)
@@ -419,7 +419,7 @@ class UsersLib extends TikiLib {
 			    $randompass = $this->genPass();
 			    // in case CAS auth is turned off accidentally;
 			    // we don't want ppl to be able to login as any user with blank passwords
-			    $result = $this->add_user($user, $randompass, '', '');
+			    $result = $this->add_user($user, $randompass, '');
 
 			    // if it worked ok, just log in
 			    if ($result == USER_VALID)
@@ -502,7 +502,7 @@ class UsersLib extends TikiLib {
 		// see if we can create a new account
 		if ($create_tiki) {
 		    // need to make this better! *********************************************************
-		    $result = $this->add_user($user, $pass, '', '');
+		    $result = $this->add_user($user, $pass, '');
 
 		    // if it worked ok, just log in
 		    if ($result == USER_VALID)
@@ -1699,7 +1699,7 @@ function get_included_groups($group) {
 			$cachelib->invalidate('userslist');
     }
 
-    function add_user($user, $pass, $email, $provpass = '', $valid=NULL, $realName='') {
+    function add_user($user, $pass, $email, $provpass = '', $valid=NULL) {
 	global $pass_due, $tikilib, $cachelib, $patterns;
 	global $feature_clear_passwords;
 	// Generate a unique hash; this is also done below in set_user_fields()
@@ -1750,12 +1750,6 @@ function get_included_groups($group) {
 	return true;
     }
 
-	function change_user_name($username, $realname) {
-		$query = "update `tiki_user_preferences` set `value`='$realname' where `user`='$username' and `prefName`='realName'";
-		$result = $this->query($query);
-		return true;
-	}
-
     function change_user_email($user, $email, $pass) {
     // Need to change the email-address for notifications, too
 	global $notificationlib; include_once('lib/notifications/notificationlib.php');
@@ -1804,10 +1798,6 @@ function get_included_groups($group) {
         return $this->getOne("select `email` from `users_users` where " . $this->convert_binary(). " `login`=?", array($user));
     }
 
-    function get_user_name($username) {
-		$query = "select `value` from `tiki_user_preferences` where `user`=? and `prefName`=?";
-        return $this->getOne($query, array($username, 'realName'));
-    }
 
     /**
      *  Returns the contact users' email if set and permitted by Admin->Features settings
