@@ -1,8 +1,8 @@
 <?php
 /*
- * $Header: /cvsroot/tikiwiki/tiki/lib/wiki-plugins/wikiplugin_quote.php,v 1.5.4.2 2005/10/14 17:10:04 sylvieg Exp $
+ * $Header: /cvsroot/tikiwiki/tiki/lib/wiki-plugins/wikiplugin_quote.php,v 1.5.4.4 2008/03/20 19:32:34 sylvieg Exp $
  *
- * TikiWiki QUOTE plugin.
+ * Tikiwiki QUOTE plugin.
  * 
  * Syntax:
  * 
@@ -17,7 +17,6 @@ function wikiplugin_quote_help() {
 
 function wikiplugin_quote($data, $params) {
 	/* set default values for some args */
-	$replyto = '';
 	
 	// Remove first <ENTER> if exists...
 //	if (substr($data, 0, 2) == "\r\n") $data = substr($data, 2);
