@@ -1,10 +1,19 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/remote.php,v 1.1.2.8 2007/03/02 12:23:23 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/remote.php,v 1.1.2.9 2008/02/21 20:40:00 marclaporte Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
+include 'tiki-setup.php';
+
+if ($feature_intertiki != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_intertiki");
+	$smarty->display("error.tpl");
+	die;
+}
+
+
 $version = "0.2";
 
 /*
@@ -54,11 +63,11 @@ $s = new XML_RPC_Server($map);
 function validate($params) {
 	global $tikilib,$userlib,$known_hosts,$intertiki_errfile,$intertiki_logfile,$logslib;
 
-	$key = $params->getParam(0); $key = $key->scalarval(); 
-	$login = $params->getParam(1); $login = $login->scalarval(); 
-	$pass = $params->getParam(2); $pass = $pass->scalarval(); 
+	$key = $params->getParam(0); $key = $key->scalarval();
+	$login = $params->getParam(1); $login = $login->scalarval();
+	$pass = $params->getParam(2); $pass = $pass->scalarval();
 	$slave = $params->getParam(3); $slave = $slave->scalarval();
-	
+
 	if (!isset($known_hosts[$key]) or $known_hosts[$key]['ip'] != $_SERVER['REMOTE_ADDR']) {
 		$msg = tra('Invalid server key');
 		if ($intertiki_errfile) logit($intertiki_errfile,$msg,$key,INTERTIKI_BADKEY,$known_hosts[$key]['name']);
@@ -77,9 +86,9 @@ function validate($params) {
 		} else {
 		    return new XML_RPC_Response(0, 101, $msg);
 		}
-	} 
+	}
 	if ($intertiki_logfile) logit($intertiki_logfile,"logged",$login,INTERTIKI_OK,$known_hosts[$key]['name']);
-	
+
 	if ($slave) {
 	    $logslib->add_log('intertiki','auth granted from '.$known_hosts[$key]['name'],$login);
 	    global $userlib;
