@@ -1,8 +1,8 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-admin_include_wiki.php,v 1.26.2.19 2006/03/30 03:51:58 sampaioprimo Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-admin_include_wiki.php,v 1.26.2.25 2007/06/09 21:30:47 nkoth Exp $
 
-// Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
@@ -209,6 +209,30 @@ if (isset($_REQUEST['wikilistprefs'])) {
 	}
 
 	$smarty->assign('wiki_list_size', isset($_REQUEST['wiki_list_size']) ? 'y' : 'n');
+
+	if (isset($_REQUEST['wiki_list_language'])) {
+		$tikilib->set_preference('wiki_list_language', 'y');
+	} else {
+		$tikilib->set_preference('wiki_list_language', 'n');
+	}
+
+	$smarty->assign('wiki_list_language', isset($_REQUEST['wiki_list_language']) ? 'y' : 'n');
+
+	if (isset($_REQUEST['wiki_list_categories'])) {
+		$tikilib->set_preference('wiki_list_categories', 'y');
+	} else {
+		$tikilib->set_preference('wiki_list_categories', 'n');
+	}
+
+	$smarty->assign('wiki_list_categories_path', isset($_REQUEST['wiki_list_categories_path']) ? 'y' : 'n');
+	if (isset($_REQUEST['wiki_list_categories_path'])) {
+		$tikilib->set_preference('wiki_list_categories_path', 'y');
+	} else {
+		$tikilib->set_preference('wiki_list_categories_path', 'n');
+	}
+
+	$smarty->assign('wiki_list_categories_path', isset($_REQUEST['wiki_list_categories_path']) ? 'y' : 'n');
+
 }
 
 if (isset($_REQUEST["wikifeatures"])) {
@@ -358,6 +382,16 @@ if (isset($_REQUEST["wikifeatures"])) {
 
 		$smarty->assign("feature_wiki_export", 'n');
 	}
+
+	if (isset($_REQUEST["feature_wiki_import_page"]) && $_REQUEST["feature_wiki_import_page"] == "on") {
+		$tikilib->set_preference("feature_wiki_import_page", 'y');
+
+		$smarty->assign("feature_wiki_import_page", 'y');
+	} else {
+		$tikilib->set_preference("feature_wiki_import_page", 'n');
+
+		$smarty->assign("feature_wiki_import_page", 'n');
+	}
 	
 	if (isset($_REQUEST["feature_wiki_rankings"]) && $_REQUEST["feature_wiki_rankings"] == "on") {
 		$tikilib->set_preference("feature_wiki_rankings", 'y');
@@ -647,6 +681,14 @@ if (isset($_REQUEST["wikisetprefs"])) {
 		$tikilib->set_preference("feature_wiki_history_ip", 'y');
 		$smarty->assign('feature_wiki_history_ip', 'y');
 	}	
+	if (isset($_REQUEST["feature_wiki_history_full"]) && $_REQUEST["feature_wiki_history_full"] == "on") {
+		$tikilib->set_preference("feature_wiki_history_full", 'y');
+		$smarty->assign('feature_wiki_history_full', 'y');
+	}
+	else {
+		$tikilib->set_preference("feature_wiki_history_full", 'n');
+		$smarty->assign('feature_wiki_history_full', 'n');
+	}	
 
 }
 
