@@ -1,12 +1,18 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/tiki-blogs_rss.php,v 1.26.2.9 2007/03/02 12:23:32 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-blogs_rss.php,v 1.26.2.10 2008/02/21 20:37:42 marclaporte Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
 require_once ('tiki-setup.php');
-require_once ('lib/tikilib.php');
+
+if ($feature_blogs != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_blogs");
+	$smarty->display("error.tpl");
+	die;
+}
+
 require_once ('lib/blogs/bloglib.php');
 require_once ('lib/rss/rsslib.php');
 
@@ -39,7 +45,7 @@ if ($output["data"]=="EMPTY") {
 	if ($tmp<>'') $title = $tmp;
 	$tmp = $tikilib->get_preference('desc_rss_'.$feed, '');
 	if ($desc<>'') $desc = $tmp;
-	
+
 	$changes = $bloglib -> list_all_blog_posts(0, $max_rss_blogs, $dateId.'_desc', '', $now);
 	$tmp = array();
 	foreach ($changes["data"] as $data)  {
