@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-chat_users.php,v 1.10.2.3 2007/03/02 12:23:29 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-chat_users.php,v 1.10.2.4 2008/02/21 19:52:40 lphuberdeau Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -9,6 +9,13 @@
 $section = 'chat';
 require_once ("tiki-setup.php");
 
+if ($feature_chat != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_chat");
+
+	$smarty->display("error.tpl");
+	die;
+}
+
 include_once ('lib/chat/chatlib.php');
 
 if (isset($_REQUEST['channelId'])) {
