@@ -1,12 +1,12 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/tiki-index.php,v 1.113.2.51 2006/04/24 11:26:50 ohertel Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-index.php,v 1.113.2.59 2007/09/05 15:09:58 sylvieg Exp $
 
-// Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
 // Initialization
-
+$section='wiki';
 require_once('tiki-setup.php');
 include_once('lib/structures/structlib.php');
 include_once('lib/wiki/wikilib.php');
@@ -141,8 +141,8 @@ if(empty($info) && !($user && $feature_wiki_userpage == 'y' && strcasecmp($featu
   $likepages = $wikilib->get_like_pages($page);
   /* if we have exactly one match, redirect to it */
   if(count($likepages) == 1  && !$isUserPage) {
-    header ("Status: 402 Found"); /* PHP3 */
-    header ("HTTP/1.0 402 Found"); /* PHP4 */
+    header ("Status: 302 Found"); /* PHP3 */
+    header ("HTTP/1.0 302 Found"); /* PHP4 */
     header("Location: tiki-index.php?page=$likepages[0]");
     die;
   }
@@ -202,6 +202,10 @@ if ($tiki_p_admin != 'y' && $feature_categories == 'y' && !$object_has_perms) {
     	foreach ($perms_array as $perm => $value) {
     		$$perm = $value;
     	}
+		if ($tiki_p_view_categories == 'y' || $tiki_p_admin_categories == 'y') {
+			$tiki_p_view = 'y';
+			$smarty->assign('tiki_p_view', 'y');
+		}
    	} else {
    		$is_categorized = FALSE;
    	}
@@ -387,6 +391,9 @@ if(isset($_REQUEST['refresh'])) {
 if(!isset($info["is_html"])) {
     $info["is_html"]=false;
 }
+$cat_type='wiki page';
+$cat_objid = $page;
+include_once('tiki-section_options.php');
 
 $smarty->assign('cached_page','n');
 if(isset($info['wiki_cache'])) {$wiki_cache=$info['wiki_cache'];}
@@ -475,7 +482,8 @@ if($feature_wiki_attachments == 'y') {
 	    $data = '';
 	    $fhash='';
 	    if($w_use_db == 'n') {
-		$fhash = md5($name = $_FILES['userfile1']['name']);    
+		$name = $_FILES['userfile1']['name'].date('U');
+		$fhash = md5($name);
 		$fw = fopen($w_use_dir.$fhash,"wb");
 		if(!$fw) {
 		    $smarty->assign('msg',tra('Cannot write to this file:').$fhash);
@@ -510,10 +518,6 @@ if($feature_wiki_attachments == 'y') {
     $smarty->assign('atts_count',count($atts["data"]));
 }
 
-$section='wiki';
-$smarty->assign('section',$section);
-include_once('tiki-section_options.php');
-
 $smarty->assign('footnote','');
 $smarty->assign('has_footnote','n');
 if($feature_wiki_footnotes == 'y') {
@@ -527,12 +531,6 @@ if($feature_wiki_footnotes == 'y') {
 
 $smarty->assign('wiki_extras','y');
 
-$cat_type='wiki page';
-$cat_objid = $page;
-if($feature_theme_control == 'y') {
-    include('tiki-tc.php');
-}
-
 // Watches
 if($feature_user_watches == 'y') {
     if($user && isset($_REQUEST['watch_event'])) {
