@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-login_validate.php,v 1.9.2.9 2007/03/02 12:23:14 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-login_validate.php,v 1.9.2.11 2008/02/25 22:59:09 lphuberdeau Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -9,6 +9,13 @@
 // Initialization
 require_once ('tiki-setup.php');
 
+if ($validateUsers != 'y' && $validateRegistration != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": validateUsers");
+
+	$smarty->display("error.tpl");
+	die;
+}
+
 $isvalid = false;
 if (isset($_REQUEST["user"])) {
 	if (isset($_REQUEST["pass"])) {
