@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-minical_reminders.php,v 1.9.2.3 2007/03/02 12:23:14 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-minical_reminders.php,v 1.9.2.4 2008/02/21 19:35:58 lphuberdeau Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -10,6 +10,13 @@ include_once ('tiki-setup_base.php');
 
 include_once ('lib/minical/minicallib.php');
 
+if ($feature_minical != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_minical");
+
+	$smarty->display("error.tpl");
+	die;
+}
+
 if (!$minical_reminders)
 	die;
 
