@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-setup.php,v 1.240.2.170 2007/12/22 05:14:33 mose Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-setup.php,v 1.240.2.175 2008/03/21 18:30:57 kerrnel22 Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -14,7 +14,7 @@
 */
 
 //this script may only be included - so its better to die if called directly.
-if (strpos($_SERVER["SCRIPT_NAME"],"tiki-setup.php")!=FALSE) {
+if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
   header("location: index.php");
   exit;
 }
@@ -2051,18 +2051,14 @@ if ($language == 'ar' || $language == 'he' || $language == 'fa') {
 }
 
 
-// HARDCODED on purpose !
-// this block should be changed at release time.
-// as well as changing http://tikiwiki.org/stable.version
-
-$tiki_version = '1.9.9';
-$tiki_branch = 'stable';
-$tiki_star = 'Sirius';
-$tiki_uses_cvs = is_dir('CVS') ? 'y' : 'n';
-
-$smarty->assign('tiki_version', $tiki_version);
-$smarty->assign('tiki_branch', $tiki_branch);
-$smarty->assign('tiki_star', $tiki_star);
-$smarty->assign('tiki_uses_cvs', $tiki_uses_cvs);
+// Set version information for other scripts.
+// Please update the lib/twversion.class.php script at release time
+// as well as adding new release to http://tikiwiki.org/{$branch}.version
+include_once ('lib/twversion.class.php');
+$TWV = new TWVersion();
+$smarty->assign('tiki_version', $TWV->version);
+$smarty->assign('tiki_branch', $TWV->branch);
+$smarty->assign('tiki_star', $TWV->star);
+$smarty->assign('tiki_uses_cvs', $TWV->cvs);
 
 
