@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-view_blog_post_image.php,v 1.5.2.2 2007/03/02 12:23:22 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-view_blog_post_image.php,v 1.5.2.3 2008/02/21 20:33:31 marclaporte Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -9,6 +9,13 @@
 // Initialization
 require_once ('tiki-setup.php');
 
+if ($feature_blogs != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_blogs");
+
+	$smarty->display("error.tpl");
+	die;
+}
+
 include_once ('lib/blogs/bloglib.php');
 
 if (!isset($_REQUEST["imgId"])) {
