@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-view_tracker.php,v 1.72.2.81 2007/10/03 12:47:13 sylvieg Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-view_tracker.php,v 1.72.2.84 2008/04/04 17:27:56 kerrnel22 Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -256,6 +256,40 @@ for ($i = 0; $i < $temp_max; $i++) {
 			} else {
 				$ins_fields["data"][$i]["value"] = date("U");
 			}
+		} else if ($fields["data"][$i]["type"] == 'F') { // date only
+			$fields["data"][$i]["value"] = '';
+			$ins_fields["data"][$i]["value"] = '';
+			if (isset($_REQUEST["$ins_id" . "Day"])) {
+				if ($_REQUEST["$ins_id" . "Month"] == 'null')   $xxxm = '00';
+				if ($_REQUEST["$ins_id" . "Day"] == 'null')     $xxxd = '00';
+				if ($_REQUEST["$ins_id" . "Year"] == 'null')    $xxxy = '00';
+				if ($xxxm == $xxxd && $xxxd == $xxxy && $xxxy == '00') {
+					$ins_fields["data"][$i]["value"] = '';
+				} else {
+					$dc = $tikilib->get_date_converter($user);
+					if ($xxxm == 'null') {
+						$xxxm = $dc->month;
+					} else {
+						$xxxm = $_REQUEST["$ins_id" . "Month"];
+					}
+					if ($xxxd == 'null') {
+						$xxxd = $dc->day;
+					} else {
+						$xxxd = $_REQUEST["$ins_id" . "Day"];
+					}
+					if ($xxxy == 'null') {
+						$xxxy = $dc->year;
+					} else {
+						$xxxy = $_REQUEST["$ins_id" . "Year"];
+					}
+					$ins_fields["data"][$i]["value"] = $dc->getServerDateFromDisplayDate(mktime(0, 0, 0, $xxxm, $xxxd, $xxxy));
+				}
+			} else {
+				if ($ins_fields["data"][$i]["isMandatory"] == "y") {
+					$fields["data"][$i]["value"] = date("U");
+					$ins_fields["data"][$i]["value"] = $fields["data"][$i]["value"];
+				}
+			}
 		} elseif ($fields["data"][$i]["type"] == 'e') { // category
 			include_once('lib/categories/categlib.php');
 			$parentId = $fields["data"][$i]["options"];
@@ -344,13 +378,15 @@ for ($i = 0; $i < $temp_max; $i++) {
 				$textarea_options = true;
 			} 
 			
-		} elseif($fields["data"][$i]["type"] == 's') { // rating
-			if (isset($_REQUEST["$ins_id"])) {
-				$newItemRate = $_REQUEST["$ins_id"];
-				$newItemRateField = $fields["data"]["$i"]["fieldId"];
-			} else {
-				$newItemRate = NULL;
-			}
+		} elseif($fields["data"][$i]["type"] == 's') { // system - special
+			if ($fields["data"][$i]["name"] == "Rating") { // Rating
+				if (isset($_REQUEST["$ins_id"])) {
+					$newItemRate = $_REQUEST["$ins_id"];
+					$newItemRateField = $fields["data"]["$i"]["fieldId"];
+				} else {
+					$newItemRate = NULL;
+				}
+			} // Do nothing for "ItemID" here.
 		
 		} elseif(  $fields["data"][$i]["type"] == 'y' ) { // country list
 			if (isset($_REQUEST["$ins_id"])) {		
@@ -684,16 +720,16 @@ if ($tracker_info['useAttachments'] == 'y' && $tracker_info['showAttachments'] =
 	}
 }
 
-/* ************** not merge needed from 1.8
+// If the special system ItemID field is set, then
+// generate static item ID's
 foreach ($items["data"] as $itkey=>$oneitem) {
     foreach ($oneitem['field_values'] as $ifld=>$valfld) {
-        if ($valfld['type'] == 'f') {
-            $items["data"][$itkey]['field_values'][$ifld]['value'] =
-                smarty_make_timestamp($valfld['value']);
+        if ($valfld['type'] == 's' && $valfld['name'] == "ItemID") {
+            $items["data"][$itkey]['field_values'][$ifld]['value'] = $oneitem['itemId'];
         }
     }
 }
-******************** */
+
 $smarty->assign('trackerId', $_REQUEST["trackerId"]);
 $smarty->assign('tracker_info', $tracker_info);
 if (isset($fields['data']))
@@ -724,9 +760,11 @@ foreach ($fields['data'] as $it) {
 }
 }
 
+// Set special system field vars
 if ($items['data']) {
 	foreach ($items['data'] as $f=>$v) {
 		$items['data'][$f]['my_rate'] = $tikilib->get_user_vote("tracker.".$_REQUEST["trackerId"].'.'.$items['data'][$f]['itemId'],$user);
+		$items['data'][$f]['ItemID']['value'] = $f;
 	}
 }
 
