@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-view_tracker_item.php,v 1.69.2.102 2007/12/10 04:28:34 kerrnel22 Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-view_tracker_item.php,v 1.69.2.103 2008/04/04 16:49:45 kerrnel22 Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -252,7 +252,37 @@ foreach($xfields["data"] as $i=>$array) {
 			} else {
 				$ins_fields["data"][$i]["value"] = date("U");
 			}
-		
+		} elseif ($fields["data"][$i]["type"] == 'F') {
+			$fields["data"][$i]["value"] = '';
+			$ins_fields["data"][$i]["value"] = '';
+			if (isset($_REQUEST["$ins_id" . "Day"])) {
+				if ($_REQUEST["$ins_id" . "Month"] == 'null')	$xxxm = '00';
+				if ($_REQUEST["$ins_id" . "Day"] == 'null')		$xxxd = '00';
+				if ($_REQUEST["$ins_id" . "Year"] == 'null')	$xxxy = '00';
+				if ($xxxm == $xxxd && $xxxd == $xxxy && $xxxy == '00') {
+					$ins_fields["data"][$i]["value"] = '';
+				} else {
+					$dc = $tikilib->get_date_converter($user);
+					if ($xxxm == 'null') {
+						$xxxm = $dc->month;
+					} else {
+						$xxxm = $_REQUEST["$ins_id" . "Month"];
+					}
+					if ($xxxd == 'null') {
+						$xxxd = $dc->day;
+					} else {
+						$xxxd = $_REQUEST["$ins_id" . "Day"];
+					}
+					if ($xxxy == 'null') {
+						$xxxy = $dc->year;
+					} else {
+						$xxxy = $_REQUEST["$ins_id" . "Year"];
+					}
+					$ins_fields["data"][$i]["value"] = $dc->getServerDateFromDisplayDate(mktime(0, 0, 0, $xxxm, $xxxd, $xxxy));
+				}
+			} else {
+				$ins_fields["data"][$i]["value"] = date("U");
+			}
 		} elseif ($fields["data"][$i]["type"] == 'e') {
 			include_once('lib/categories/categlib.php');
 			$k = $ins_fields["data"][$i]["options"];
