@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-webmail.php,v 1.25.2.16 2007/08/12 18:22:35 mose Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-webmail.php,v 1.25.2.17 2008/01/31 20:20:29 marclaporte Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -12,7 +12,7 @@ require_once ('tiki-setup.php');
 include_once ('lib/webmail/webmaillib.php');
 
 if ($feature_webmail != 'y') {
-	$smarty->assign('msg', tra("This feature is disabled").": feature_wiki");
+	$smarty->assign('msg', tra("This feature is disabled").": feature_webmail");
 
 	$smarty->display("error.tpl");
 	die;
@@ -105,7 +105,7 @@ function decode_subject_utf8($string){
 		return mb_convert_encoding($str, "utf-8", $string[1]);
 	else
 		return $str;
-} 
+}
 
 if (!$user) {
 	$smarty->assign('msg', tra("You are not logged in"));
@@ -166,7 +166,7 @@ if ($_REQUEST["locSection"] == 'read') {
 	} elseif (isset($aux["Message-id"])) {
 		$aux["Message-ID"] = $aux["Message-id"];
 	}
-	if (!isset($aux["Message-ID"])) { 
+	if (!isset($aux["Message-ID"])) {
 		$aux["Message-ID"] = 'unknown';
 	}
 	$message = $pop3->getMsg($_REQUEST["msgid"]);
@@ -399,7 +399,7 @@ if ($_REQUEST["locSection"] == 'mailbox') {
 			} elseif (isset($aux["Message-id"])) {
 				$aux["Message-ID"] = $aux["Message-id"];
 			}
-			if (!isset($aux["Message-ID"])) { 
+			if (!isset($aux["Message-ID"])) {
 				$aux["Message-ID"] = 'unknown'.time();
 			}
 			$aux["subject"] = decode_subject_utf8($aux["Subject"]);
@@ -448,7 +448,7 @@ if ($_REQUEST["locSection"] == 'mailbox') {
 			} elseif (isset($aux["Message-id"])) {
 				$aux["Message-ID"] = $aux["Message-id"];
 			}
-			if (!isset($aux["Message-ID"])) { 
+			if (!isset($aux["Message-ID"])) {
 				$aux["Message-ID"] = 'unknown'.time();
 			}
 			preg_match('/<?([-!#$%&\'*+\.\/0-9=?A-Z^_`a-z{|}~]+@[-!#$%&\'*+\/0-9=?A-Z^_`a-z{|}~]+(\.[-!#$%&\'*+\.\/0-9=?A-Z^_`a-z{|}~]+)?)>?/',$aux["From"],$mail);
@@ -457,7 +457,7 @@ if ($_REQUEST["locSection"] == 'mailbox') {
 			$aux["timestamp"] = strtotime($aux['Date']);
 			$l = $pop3->_cmdList($i);
 			$aux["size"] = $l["size"];
-			
+
 			//print_r($aux);print("<br />");
 			$aux["realmsgid"] = ereg_replace("[<>]","",$aux["Message-ID"]);
 			$webmaillib->replace_webmail_message($current["accountId"], $user, $aux["realmsgid"]);
