@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-webmail_contacts.php,v 1.8.2.5 2007/03/02 12:23:29 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-webmail_contacts.php,v 1.8.2.6 2008/01/31 20:34:56 marclaporte Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -11,6 +11,23 @@ require_once ('tiki-setup.php');
 
 include_once ('lib/webmail/webmaillib.php');
 
+
+if ($feature_webmail != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_webmail");
+
+	$smarty->display("error.tpl");
+	die;
+}
+
+if ($tiki_p_use_webmail != 'y') {
+	$smarty->assign('msg', tra("Permission denied to use this feature"));
+
+	$smarty->display("error.tpl");
+	die;
+}
+
+
+
 $smarty->assign('element', $_REQUEST["element"]);
 
 if (!isset($_REQUEST["contactId"])) {
