@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-webmail_download_attachment.php,v 1.6.2.3 2007/03/02 12:23:23 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-webmail_download_attachment.php,v 1.6.2.4 2008/01/31 20:34:56 marclaporte Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -9,6 +9,20 @@
 // Initialization
 require_once ('tiki-setup.php');
 
+if ($feature_webmail != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_webmail");
+
+	$smarty->display("error.tpl");
+	die;
+}
+
+if ($tiki_p_use_webmail != 'y') {
+	$smarty->assign('msg', tra("Permission denied to use this feature"));
+
+	$smarty->display("error.tpl");
+	die;
+}
+
 require_once ('lib/webmail/webmaillib.php');
 
 require ("lib/webmail/mimeDecode.php");
